<?php
// SPDX-License-Identifier: EUPL-1.2
// Authors: see README.md

namespace SeaCMS\Api;

use Exception;
use SeaCMS\Api\JsonResponse;
use Throwable;

/**
 * Exception for bad http method
 */
class SpecialOutputException extends Exception
{
    /**
     * jsonResponse of the Exception
     * @var JsonResponse
     */
    protected $jsonResponse;

    // Redefine the exception to be able to define $jsonResponse
    public function __construct($message = "", $code = 0, ?Throwable $previous = null, ?JsonResponse $jsonResponse = null) {
        if ($message instanceof JsonResponse){
            $this->jsonResponse = $message;
            $message = "Forced output with JsonResponse";
            if (!is_integer($code)){
                $int = 0;
            }
        } else {
            if (!is_string($message)){
                $message = "";
            }
            if ($code instanceof JsonResponse){
                $this->jsonResponse = $code;
                $code = 0;
            } else {
                if (!is_integer($code)){
                    $int = 0;
                }
                if (is_null($jsonResponse)){
                    throw new Exception("It is not possible to instanciate a SpecialOutputException because \$jsonResponse is null !");
                } else {
                    $this->jsonResponse = $jsonResponse;
                }
            }
        }

        // make sure everything is assigned properly
        parent::__construct($message, $code, $previous);
    }

    /**
     * get JsonResponse
     * @return JsonResponse
     */
    public function getJsonResponse(): JsonResponse
    {
        return $this->jsonResponse;
    }
}